@@ -18,8 +18,8 @@ typedef struct prof_call_trees_t
 } prof_call_trees_t;
 
 
-void rp_init_call_trees();
-prof_call_trees_t* prof_call_trees_create();
+void rp_init_call_trees(void);
+prof_call_trees_t* prof_call_trees_create(void);
 void prof_call_trees_free(prof_call_trees_t* call_trees);
 prof_call_trees_t* prof_get_call_trees(VALUE self);
 void prof_add_call_tree(prof_call_trees_t* call_trees, prof_call_tree_t* call_tree);
