@@ -30,7 +30,7 @@ class UniqueCallPathTest < TestCase
   def test_root
     unique_call_path = UniqueCallPath.new
 
-    result = RubyProf.profile do
+    result = RubyProf::Profile.profile do
       unique_call_path.method_a(1)
     end
 
@@ -41,7 +41,7 @@ class UniqueCallPathTest < TestCase
   def test_root_children
     unique_call_path = UniqueCallPath.new
 
-    result = RubyProf.profile do
+    result = RubyProf::Profile.profile do
       unique_call_path.method_a(1)
       unique_call_path.method_k(2)
     end
@@ -59,7 +59,7 @@ class UniqueCallPathTest < TestCase
   def test_children_of
     unique_call_path = UniqueCallPath.new
 
-    result = RubyProf.profile do
+    result = RubyProf::Profile.profile do
       unique_call_path.method_a(1)
       unique_call_path.method_k(2)
     end
@@ -79,14 +79,15 @@ class UniqueCallPathTest < TestCase
       array
     end
 
-    assert_equal(1, call_info_a.children.length)
-    assert_equal("UniqueCallPath#method_b", call_info_a.children.first.target.full_name)
+    assert_equal(2, call_info_a.children.length)
+    assert_equal("Integer#==", call_info_a.children[0].target.full_name)
+    assert_equal("UniqueCallPath#method_b", call_info_a.children[1].target.full_name)
   end
 
   def test_unique_path
     unique_call_path = UniqueCallPath.new
 
-    result = RubyProf.profile do
+    result = RubyProf::Profile.profile do
       unique_call_path.method_a(1)
       unique_call_path.method_k(1)
     end
@@ -106,15 +107,17 @@ class UniqueCallPathTest < TestCase
       array
     end
 
-    assert_equal(1, call_info_a.children.length)
-    assert_equal(1, children_of_a.length)
-
     children_of_a = children_of_a.sort do |c1, c2|
       c1.target.full_name <=> c2.target.full_name
     end
 
-    assert_equal(1, children_of_a.length)
+    assert_equal(2, call_info_a.children.length)
+    assert_equal(2, children_of_a.length)
+
     assert_equal(1, children_of_a[0].called)
-    assert_equal("UniqueCallPath#method_b", children_of_a[0].target.full_name)
+    assert_equal("Integer#==", children_of_a[0].target.full_name)
+
+    assert_equal(1, children_of_a[1].called)
+    assert_equal("UniqueCallPath#method_b", children_of_a[1].target.full_name)
   end
 end
